import * as amqp from 'amqplib';
import { Broker } from './interface';
import { ProcessFunc } from '../consumer';
import { Task, TaskMeta } from '../common';
export interface AMQPBrokerOptions {
    /**
     *  Amqp url, default 'amqp://localhost'
     */
    url?: string;
    /**
     *  The queue name is in the form of `${taskName}_${queueSuffix}`, default 'queue'
     */
    queueSuffix?: string;
    /**
     *  Amqp exchange name, please be sure it is same as it in the producer, default 'worker-exchange'
     */
    exchangeName?: string;
    /**
     *  Amqp exchange name, default: 'direct'
     */
    exchangeType?: string;
    /**
     *  Options for assert exchange
     */
    exchangeOptions?: amqp.Options.AssertExchange;
    /**
     *  Options for assert queue (consumer)
     */
    queueOptions?: amqp.Options.AssertQueue;
    /**
     *  Socket options for amqp connec
     */
    socketOptions?: any;
}
export declare class AMQPBroker extends Broker {
    private options;
    private connection;
    private isConnecting;
    private producerChannel;
    private isProducerChannelCreating;
    private taskRegisterMap;
    private taskRegisterWaitQueue;
    private taskWaitQueue;
    private checkJob;
    constructor(options?: AMQPBrokerOptions);
    private createConnection();
    private getConnection();
    private createProducerChannel();
    private createConsumerChannel(register);
    private getProducerChannel();
    private drainQueue();
    private checkConsumerConnection();
    private createChannelAndConsume(taskRegister);
    private retryTask(task);
    private consume(taskRegister);
    private send(task);
    registerTask(taskMeta: TaskMeta, processFunc: ProcessFunc): Promise<void>;
    publish(task: Task): Promise<any>;
    checkHealth(): Promise<any>;
    close(): Promise<void>;
}
